#############################################################################
#                                                                           #
#    This file is part of Jaop                                              #
#                                                                           #
#    Jaop is free software: you can redistribute it and/or modify           #
#    it under the terms of the GNU General Public License as published by   #
#    the Free Software Foundation, either version 3 of the License, or      #
#    (at your option) any later version.                                    #
#                                                                           #
#    Jaop is distributed in the hope that it will be useful,                #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of         #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
#    GNU General Public License for more details.                           #
#                                                                           #
#    You should have received a copy of the GNU General Public License      #
#    along with Jaop.  If not, see <http://www.gnu.org/licenses/>.          #
#                                                                           #
#############################################################################

from zope.interface import Interface, implements
from zope.component import adapts, getUtility
from zope.formlib.form import FormFields
from zope.schema import TextLine, List, Bool
from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.CMFPlone import PloneMessageFactory as _
from Products.CMFCore.interfaces import IPropertiesTool
from plone.app.controlpanel.form import ControlPanelForm


class IOpenSearchSettingsForm(Interface):
    """ The view for the open search prefs form """

    description = TextLine(title=_(u'Description'),
                           description=_(u'A human-readable description of the'
                                         'search engine.'))

    tags = List(title=_(u'Tags'),
                description=_(u'Tags, one per line.'))

    contact = TextLine(title=_(u'Contact'),
                       description=_(u'An email address of someone to contact.'))

    allowRSS = Bool(title=_(u'Allow OpenSearch via RSS'),
                    description=_(u'Allow OpenSearch via RSS'))

    allowAtom = Bool(title=_(u'Allow OpenSearch via Atom'),
                     description=_(u'Allow OpenSearch via Atom'))

    allowXHTML = Bool(title=_(u'Allow OpenSearch via XHTML + xml'),
                      description=_(u'Allow OpenSearch via XHTML + xml'))
                     

class OpenSearchControlPanelAdapter(SchemaAdapterBase):
    adapts(IPloneSiteRoot)
    implements(IOpenSearchSettingsForm)

    def __init__(self, context):
        super(OpenSearchControlPanelAdapter, self).__init__(context)
        pt = getUtility(IPropertiesTool)
        self.osprops = pt.opensearch_properties

    def get_description(self):
        return self.osprops.Description

    def set_description(self, desc):
        self.osprops.Description = desc

    description = property(get_description, set_description)


class OpenSearchPrefsForm(ControlPanelForm):
    """ """
    implements(IOpenSearchSettingsForm)
    form_fields = FormFields(FormFields(IOpenSearchSettingsForm))

    label = _(u'Open Search Settings Form')
    description = _(u'stuff')
    form_name = _(u'OpenSearch Settings')


                           

